package com.ruoyi.framework.config;

import com.ruoyi.common.exception.user.UserPasswordNotMatchException;

import com.ruoyi.framework.web.service.UserDetailsServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Component;

@Component
public class MyAuthenticationProvider implements AuthenticationProvider {

    @Autowired
    private UserDetailsServiceImpl userDetailsService;

    @Autowired
    private BCryptPasswordEncoder bCryptPasswordEncoder;

    @Override
    public Authentication authenticate(Authentication authentication)    throws AuthenticationException,UserPasswordNotMatchException {
        String name=authentication.getName();
        String password=(String)authentication.getCredentials();
        UserDetails user=userDetailsService.loadUserByUsername(name);
        String encoderPassword=bCryptPasswordEncoder.encode(password);
        //查找出账号 想用数据库的校验能通过就通过
        if (bCryptPasswordEncoder.matches(password,user.getPassword())){
            return new UsernamePasswordAuthenticationToken(name, encoderPassword);
        }
        int checkLogin=checkLogin(name,password);//外部的账号密码验证接口
        if(checkLogin==2){
            return new UsernamePasswordAuthenticationToken(name, password);
        }else {
            //如果都登录不了，就返回异常输出
            throw new UserPasswordNotMatchException();
        }
    }

    @Override
    public boolean supports(Class<?> aClass) {
        return false;
    }


    /**
     * 内网 验证账号密码
     * @param userName
     * @param pwd
     * @return 2 op账号密码验证通过，3 验证不通过
     */
    public static int checkLogin(String userName, String pwd) {
        if(userName.equals(pwd)){
            return 2;
        }
        return 3;
    }
}